==> scummvm_0.11.1.orig.tar.gz: scummvm-0.11.1/tools/create_kyradat/eng.h <==
const ExtractEntry kyra1EngFloppy[] = {
	{ kKallakWritingSeq, 0x0002FE5E, 0x00030653 },
	{ kMalcolmTreeSeq, 0x00030653, 0x00030869 },
	{ kWestwoodLogoSeq, 0x00030869, 0x000308B4 },
	{ kKyrandiaLogoSeq, 0x000308B4, 0x00030910 },
	{ kKallakMalcolmSeq, 0x00030910, 0x00030B7B },
	{ kForestSeq, 0x00030B7B, 0x00030D10 },
	{ kIntroCPSStrings, 0x00030D10, 0x00030D24 },
	{ kIntroWSAStrings, 0x00030D24, 0x00030DA4 },
	{ kIntroCOLStrings, 0x00030DA4, 0x00030DCF },
	{ kIntroStrings, 0x00030DCF, 0x000312C4 },
	{ kRoomList, 0x00028020, 0x0002CDF6 },
	{ kRoomFilenames, 0x0003386A, 0x00033B46 },
	{ kCharacterImageFilenames, 0x0003268D, 0x00032771 },
	{ kDefaultShapes, 0x0002CFB0, 0x0002D43A },
	{ kItemNames, 0x00033F2E, 0x00034396 },
	{ kTakenStrings, 0x00033822, 0x00033832 },
	{ kPlacedStrings, 0x00033832, 0x0003383B },
	{ kDroppedStrings, 0x00033860, 0x0003386A },
	{ kNoDropStrings, 0x000337DA, 0x00033821 },
	{ kAmuleteAnimSeq, 0x0002EA9C, 0x0002EAC6 },
	{ kPaletteList1, 0x00025100, 0x00025115 },
	{ kPaletteList2, 0x00025115, 0x00025148 },
	{ kPaletteList3, 0x00025148, 0x0002517B },
	{ kPaletteList4, 0x0002517B, 0x000251AE },
	{ kPaletteList5, 0x000251AE, 0x000251E1 },
	{ kPaletteList6, 0x000251E1, 0x00025214 },
	{ kPaletteList7, 0x00025214, 0x0002524A },
	{ kPaletteList8, 0x0002524A, 0x00025280 },
	{ kPaletteList9, 0x00025280, 0x000252AD },
	{ kPaletteList10, 0x000252AD, 0x000252DA },
	{ kPaletteList11, 0x000252DA, 0x00025307 },
	{ kPaletteList12, 0x00025307, 0x00025334 },
	{ kPaletteList13, 0x00025334, 0x00025361 },
	{ kPaletteList14, 0x00025361, 0x0002539D },
	{ kPaletteList15, 0x0002539D, 0x000253CA },
	{ kPaletteList16, 0x000253CA, 0x000253EB },
	{ kPaletteList17, 0x000253EB, 0x0002540C },
	{ kPaletteList18, 0x0002540C, 0x00025421 },
	{ kPaletteList19, 0x00025421, 0x00025436 },
	{ kPaletteList20, 0x00025436, 0x0002544B },
	{ kPaletteList21, 0x0002544B, 0x00025460 },
	{ kPaletteList22, 0x00025460, 0x00025475 },
	{ kPaletteList23, 0x00025475, 0x0002548A },
	{ kPaletteList24, 0x0002548A, 0x000254BA },
	{ kPaletteList25, 0x000254BA, 0x000254EA },
	{ kPaletteList26, 0x000254EA, 0x0002551A },
	{ kPaletteList27, 0x0002551A, 0x0002554A },
	{ kPaletteList28, 0x0002554A, 0x0002557A },
	{ kPaletteList29, 0x0002557A, 0x000255AA },
	{ kPaletteList30, 0x000255AA, 0x000255E6 },
	{ kPaletteList31, 0x000255E6, 0x0002560D },
	{ kPaletteList32, 0x0002560D, 0x00025634 },
	{ kPaletteList33, 0x00025634, 0x00025670 },
	{ kPutDownString, 0x0002EBCE, 0x0002EBF4 },
	{ kWaitAmuletString, 0x0002EBF4, 0x0002EC31 },
	{ kBlackJewelString, 0x0002EC31, 0x0002EC54 },
	{ kHealingTipString, 0x0002EC54, 0x0002EC81 },
	{ kPoisonGoneString, 0x0002ECE7, 0x0002ED14 },
	{ kHealing1Shapes, 0x0002D4A3, 0x0002D53D },
	{ kHealing2Shapes, 0x0002D53D, 0x0002D60F },
	{ kThePoisonStrings, 0x0002F8DC, 0x0002F933 },
	{ kFluteStrings, 0x00031C7B, 0x00031CB7 },
	{ kPoisonDeathShapes, 0x0002D903, 0x0002D98F },
	{ kFluteShapes, 0x0002D807, 0x0002D903 },
	{ kWinter1Shapes, 0x0002D60F, 0x0002D640 },
	{ kWinter2Shapes, 0x0002D640, 0x0002D735 },
	{ kWinter3Shapes, 0x0002D735, 0x0002D751 },
	{ kDrinkShapes, 0x0002D43A, 0x0002D4A3 },
	{ kWispShapes, 0x0002D751, 0x0002D807 },
	{ kMagicAnimShapes, 0x0002D98F, 0x0002D9B2 },
	{ kBranStoneShapes, 0x0002D9B2, 0x0002DA20 },
	{ kWispJewelStrings, 0x0002EC81, 0x0002ECD4 },
	{ kMagicJewelStrings, 0x0002ECD4, 0x0002ECE7 },
	{ kFlaskFullString, 0x0002F9EB, 0x0002FA07 },
	{ kFullFlaskString, 0x0002F954, 0x0002F9EB },
	{ kOutroReunionSeq, 0x000313C1, 0x00031908 },
	{ kOutroHomeString, 0x000319C2, 0x000319C7 },
	{ kVeryCleverString, 0x00031922, 0x00031954 },
	{ kGUIStrings, 0x0002EE7A, 0x0002F02A },
	{ kNewGameString, 0x00032466, 0x0003247B },
	{ kConfigStrings, 0x0002f870, 0x0002f8af },
	{ -1, 0, 0 }
};

const ExtractEntry kyra1EngCD[] = {
	{ kKallakWritingSeq, 0x0003008F, 0x00030894 },
	{ kMalcolmTreeSeq, 0x00030894, 0x00030AC4 },
	{ kWestwoodLogoSeq, 0x00030AC4, 0x00030B0F },
	{ kKyrandiaLogoSeq, 0x00030B0F, 0x00030BB5 },
	{ kKallakMalcolmSeq, 0x00030BB5, 0x00030E6D },
	{ kForestSeq, 0x00030E6D, 0x000310E0 },
	{ kIntroCPSStrings, 0x000310E0, 0x000310F5 },
	{ kIntroWSAStrings, 0x000310F5, 0x00031175 },
	{ kIntroCOLStrings, 0x00031175, 0x000311A0 },
	{ kIntroStrings, 0x000311A0, 0x00031696 },
	{ kRoomList, 0x00028280, 0x0002D056 },
	{ kRoomFilenames, 0x00033F2C, 0x00034208 },
	{ kCharacterImageFilenames, 0x00032F22, 0x00033006 },
	{ kDefaultShapes, 0x0002D210, 0x0002D69A },
	{ kItemNames, 0x00034442, 0x000348AA },
	{ kTakenStrings, 0x00033EE4, 0x00033EF4 },
	{ kPlacedStrings, 0x00033EF4, 0x00033EFD },
	{ kDroppedStrings, 0x00033F22, 0x00033F2C },
	{ kNoDropStrings, 0x00033E9C, 0x00033EE3 },
	{ kAmuleteAnimSeq, 0x0002EE1C, 0x0002EE46 },
	{ kPaletteList1, 0x00025530, 0x00025545 },
	{ kPaletteList2, 0x00025545, 0x00025578 },
	{ kPaletteList3, 0x00025578, 0x000255AB },
	{ kPaletteList4, 0x000255AB, 0x000255DE },
	{ kPaletteList5, 0x000255DE, 0x00025611 },
	{ kPaletteList6, 0x00025611, 0x00025644 },
	{ kPaletteList7, 0x00025644, 0x0002567A },
	{ kPaletteList8, 0x0002567A, 0x000256B0 },
	{ kPaletteList9, 0x000256B0, 0x000256DD },
	{ kPaletteList10, 0x000256DD, 0x0002570A },
	{ kPaletteList11, 0x0002570A, 0x00025737 },
	{ kPaletteList12, 0x00025737, 0x00025764 },
	{ kPaletteList13, 0x00025764, 0x00025791 },
	{ kPaletteList14, 0x00025791, 0x000257CD },
	{ kPaletteList15, 0x000257CD, 0x000257FA },
	{ kPaletteList16, 0x000257FA, 0x0002581B },
	{ kPaletteList17, 0x0002581B, 0x0002583C },
	{ kPaletteList18, 0x0002583C, 0x00025851 },
	{ kPaletteList19, 0x00025851, 0x00025866 },
	{ kPaletteList20, 0x00025866, 0x0002587B },
	{ kPaletteList21, 0x0002587B, 0x00025890 },
	{ kPaletteList22, 0x00025890, 0x000258A5 },
	{ kPaletteList23, 0x000258A5, 0x000258BA },
	{ kPaletteList24, 0x000258BA, 0x000258EA },
	{ kPaletteList25, 0x000258EA, 0x0002591A },
	{ kPaletteList26, 0x0002591A, 0x0002594A },
	{ kPaletteList27, 0x0002594A, 0x0002597A },
	{ kPaletteList28, 0x0002597A, 0x000259AA },
	{ kPaletteList29, 0x000259AA, 0x000259DA },
	{ kPaletteList30, 0x000259DA, 0x00025A16 },
	{ kPaletteList31, 0x00025A16, 0x00025A3D },
	{ kPaletteList32, 0x00025A3D, 0x00025A64 },
	{ kPaletteList33, 0x00025A64, 0x00025AA0 },
	{ kPutDownString, 0x0002EF50, 0x0002EF76 },
	{ kWaitAmuletString, 0x0002EF76, 0x0002EFB3 },
	{ kBlackJewelString, 0x0002EFB3, 0x0002EFD6 },
	{ kHealingTipString, 0x0002EFD6, 0x0002F003 },
	{ kPoisonGoneString, 0x0002F068, 0x0002F095 },
	{ kHealing1Shapes, 0x0002D703, 0x0002D79D },
	{ kHealing2Shapes, 0x0002D79D, 0x0002D86F },
	{ kThePoisonStrings, 0x0002FCCA, 0x0002FD21 },
	{ kFluteStrings, 0x00032510, 0x000325AC },
	{ kPoisonDeathShapes, 0x0002DB63, 0x0002DBEF },
	{ kFluteShapes, 0x0002DA67, 0x0002DB63 },
	{ kWinter1Shapes, 0x0002D86F, 0x0002D8A0 },
	{ kWinter2Shapes, 0x0002D8A0, 0x0002D995 },
	{ kWinter3Shapes, 0x0002D995, 0x0002D9B1 },
	{ kDrinkShapes, 0x0002D69A, 0x0002D703 },
	{ kWispShapes, 0x0002D9B1, 0x0002DA67 },
	{ kMagicAnimShapes, 0x0002DBEF, 0x0002DC12 },
	{ kBranStoneShapes, 0x0002DC12, 0x0002DC80 },
	{ kWispJewelStrings, 0x0002F003, 0x0002F055 },
	{ kMagicJewelStrings, 0x0002F055, 0x0002F068 },
	{ kFlaskFullString, 0x0002FDE1, 0x0002FDFD },
	{ kFullFlaskString, 0x0002FD4A, 0x0002FDE1 },
	{ kOutroReunionSeq, 0x00031791, 0x00031D76 },
	{ kOutroHomeString, 0x00031E3A, 0x00031E3F },
	{ kVeryCleverString, 0x00031D90, 0x00031DC2 },
	{ kGUIStrings, 0x0002F1EE, 0x0002F3F7 },
	{ kNewGameString, 0x00032CFB, 0x00032D10 },
	{ kConfigStrings, 0x0002fc3d, 0x0002fc9e },
	{ -1, 0, 0 }
};

const ExtractEntry kyra1EngDemo[] = {
	{ kWestwoodLogoSeq, 0x00015327, 0x0001536B },
	{ kKyrandiaLogoSeq, 0x0001536B, 0x000153BF },
	{ kIntroCPSStrings, 0x000154B1, 0x000154BD },
	{ kIntroWSAStrings, 0x000154BD, 0x0001550A },
	{ kIntroCOLStrings, 0x0001550A, 0x00015550 },
	{ kIntroStrings, 0x00015550, 0x0001584A },
	{ kDemo1Seq, 0x000153BF, 0x000153E5 },
	{ kDemo2Seq, 0x000153E5, 0x00015408 },
	{ kDemo3Seq, 0x00015408, 0x00015461 },
	{ kDemo4Seq, 0x00015461, 0x00015481 },
	{ -1, 0, 0 }
};

const Game kyra1EngGames[] = {
	{ kKyra1, EN_ANY, -1, "76a4fc84e173cadb6369785787e1546e", kyra1EngFloppy },
	{ kKyra1, EN_ANY, kTalkieVersion, "1ebc18f3e7fbb72474a55cb0fa089ed4", kyra1EngCD },
	{ kKyra1, EN_ANY, kDemoVersion, "7b7504c8560ffc914d34c44c71b3094c", kyra1EngDemo },
	GAME_DUMMY_ENTRY
};

==> scummvm_1.0.0-4.tar.gz: scummvm-1.0.0/tools/create_kyradat/eng.h <==
const ExtractEntry kyra1EngFloppy[] = {
	{ kKallakWritingSeq, 0x0002FE5E, 0x00030653 },
	{ kMalcolmTreeSeq, 0x00030653, 0x00030869 },
	{ kWestwoodLogoSeq, 0x00030869, 0x000308B4 },
	{ kKyrandiaLogoSeq, 0x000308B4, 0x00030910 },
	{ kKallakMalcolmSeq, 0x00030910, 0x00030B7B },
	{ kForestSeq, 0x00030B7B, 0x00030D10 },
	{ kIntroCPSStrings, 0x00030D10, 0x00030D24 },
	{ kIntroWSAStrings, 0x00030D24, 0x00030DA4 },
	{ kIntroCOLStrings, 0x00030DA4, 0x00030DCF },
	{ kIntroStrings, 0x00030DCF, 0x000312C4 },
	{ kRoomList, 0x00028020, 0x0002CDF6 },
	{ kRoomFilenames, 0x0003386A, 0x00033B46 },
	{ kCharacterImageFilenames, 0x0003268D, 0x00032771 },
	{ kDefaultShapes, 0x0002CFB0, 0x0002D43A },
	{ kItemNames, 0x00033F2E, 0x00034396 },
	{ kTakenStrings, 0x00033822, 0x00033832 },
	{ kPlacedStrings, 0x00033832, 0x0003383B },
	{ kDroppedStrings, 0x00033860, 0x0003386A },
	{ kNoDropStrings, 0x000337DA, 0x00033821 },
	{ kAmuleteAnimSeq, 0x0002EA9C, 0x0002EAC6 },
	{ kPaletteList1, 0x00025100, 0x00025115 },
	{ kPaletteList2, 0x00025115, 0x00025148 },
	{ kPaletteList3, 0x00025148, 0x0002517B },
	{ kPaletteList4, 0x0002517B, 0x000251AE },
	{ kPaletteList5, 0x000251AE, 0x000251E1 },
	{ kPaletteList6, 0x000251E1, 0x00025214 },
	{ kPaletteList7, 0x00025214, 0x0002524A },
	{ kPaletteList8, 0x0002524A, 0x00025280 },
	{ kPaletteList9, 0x00025280, 0x000252AD },
	{ kPaletteList10, 0x000252AD, 0x000252DA },
	{ kPaletteList11, 0x000252DA, 0x00025307 },
	{ kPaletteList12, 0x00025307, 0x00025334 },
	{ kPaletteList13, 0x00025334, 0x00025361 },
	{ kPaletteList14, 0x00025361, 0x0002539D },
	{ kPaletteList15, 0x0002539D, 0x000253CA },
	{ kPaletteList16, 0x000253CA, 0x000253EB },
	{ kPaletteList17, 0x000253EB, 0x0002540C },
	{ kPaletteList18, 0x0002540C, 0x00025421 },
	{ kPaletteList19, 0x00025421, 0x00025436 },
	{ kPaletteList20, 0x00025436, 0x0002544B },
	{ kPaletteList21, 0x0002544B, 0x00025460 },
	{ kPaletteList22, 0x00025460, 0x00025475 },
	{ kPaletteList23, 0x00025475, 0x0002548A },
	{ kPaletteList24, 0x0002548A, 0x000254BA },
	{ kPaletteList25, 0x000254BA, 0x000254EA },
	{ kPaletteList26, 0x000254EA, 0x0002551A },
	{ kPaletteList27, 0x0002551A, 0x0002554A },
	{ kPaletteList28, 0x0002554A, 0x0002557A },
	{ kPaletteList29, 0x0002557A, 0x000255AA },
	{ kPaletteList30, 0x000255AA, 0x000255E6 },
	{ kPaletteList31, 0x000255E6, 0x0002560D },
	{ kPaletteList32, 0x0002560D, 0x00025634 },
	{ kPaletteList33, 0x00025634, 0x00025670 },
	{ kPutDownString, 0x0002EBCE, 0x0002EBF4 },
	{ kWaitAmuletString, 0x0002EBF4, 0x0002EC31 },
	{ kBlackJewelString, 0x0002EC31, 0x0002EC54 },
	{ kHealingTipString, 0x0002EC54, 0x0002EC81 },
	{ kPoisonGoneString, 0x0002ECE7, 0x0002ED14 },
	{ kHealing1Shapes, 0x0002D4A3, 0x0002D53D },
	{ kHealing2Shapes, 0x0002D53D, 0x0002D60F },
	{ kThePoisonStrings, 0x0002F8DC, 0x0002F933 },
	{ kFluteStrings, 0x00031C7B, 0x00031CB7 },
	{ kPoisonDeathShapes, 0x0002D903, 0x0002D98F },
	{ kFluteShapes, 0x0002D807, 0x0002D903 },
	{ kWinter1Shapes, 0x0002D60F, 0x0002D640 },
	{ kWinter2Shapes, 0x0002D640, 0x0002D735 },
	{ kWinter3Shapes, 0x0002D735, 0x0002D751 },
	{ kDrinkShapes, 0x0002D43A, 0x0002D4A3 },
	{ kWispShapes, 0x0002D751, 0x0002D807 },
	{ kMagicAnimShapes, 0x0002D98F, 0x0002D9B2 },
	{ kBranStoneShapes, 0x0002D9B2, 0x0002DA20 },
	{ kWispJewelStrings, 0x0002EC81, 0x0002ECD4 },
	{ kMagicJewelStrings, 0x0002ECD4, 0x0002ECE7 },
	{ kFlaskFullString, 0x0002F9EB, 0x0002FA07 },
	{ kFullFlaskString, 0x0002F954, 0x0002F9EB },
	{ kOutroReunionSeq, 0x000313C1, 0x00031908 },
	{ kOutroHomeString, 0x000319C2, 0x000319C7 },
	{ kVeryCleverString, 0x00031922, 0x00031954 },
	{ kGUIStrings, 0x0002EE7A, 0x0002F02A },
	{ kNewGameString, 0x00032466, 0x0003247B },
	{ kConfigStrings, 0x0002f870, 0x0002f8af },
	{ kAudioTracks, 0x00032771, 0x000327B2 },
	{ kAudioTracksIntro, 0x0002FC88, 0x0002FC8E },

	{ -1, 0, 0 }
};

const ExtractEntry kyra1EngCD[] = {
	{ kKallakWritingSeq, 0x0003008F, 0x00030894 },
	{ kMalcolmTreeSeq, 0x00030894, 0x00030AC4 },
	{ kWestwoodLogoSeq, 0x00030AC4, 0x00030B0F },
	{ kKyrandiaLogoSeq, 0x00030B0F, 0x00030BB5 },
	{ kKallakMalcolmSeq, 0x00030BB5, 0x00030E6D },
	{ kForestSeq, 0x00030E6D, 0x000310E0 },
	{ kIntroCPSStrings, 0x000310E0, 0x000310F5 },
	{ kIntroWSAStrings, 0x000310F5, 0x00031175 },
	{ kIntroCOLStrings, 0x00031175, 0x000311A0 },
	{ kIntroStrings, 0x000311A0, 0x00031696 },
	{ kRoomList, 0x00028280, 0x0002D056 },
	{ kRoomFilenames, 0x00033F2C, 0x00034208 },
	{ kCharacterImageFilenames, 0x00032F22, 0x00033006 },
	{ kDefaultShapes, 0x0002D210, 0x0002D69A },
	{ kItemNames, 0x00034442, 0x000348AA },
	{ kTakenStrings, 0x00033EE4, 0x00033EF4 },
	{ kPlacedStrings, 0x00033EF4, 0x00033EFD },
	{ kDroppedStrings, 0x00033F22, 0x00033F2C },
	{ kNoDropStrings, 0x00033E9C, 0x00033EE3 },
	{ kAmuleteAnimSeq, 0x0002EE1C, 0x0002EE46 },
	{ kPaletteList1, 0x00025530, 0x00025545 },
	{ kPaletteList2, 0x00025545, 0x00025578 },
	{ kPaletteList3, 0x00025578, 0x000255AB },
	{ kPaletteList4, 0x000255AB, 0x000255DE },
	{ kPaletteList5, 0x000255DE, 0x00025611 },
	{ kPaletteList6, 0x00025611, 0x00025644 },
	{ kPaletteList7, 0x00025644, 0x0002567A },
	{ kPaletteList8, 0x0002567A, 0x000256B0 },
	{ kPaletteList9, 0x000256B0, 0x000256DD },
	{ kPaletteList10, 0x000256DD, 0x0002570A },
	{ kPaletteList11, 0x0002570A, 0x00025737 },
	{ kPaletteList12, 0x00025737, 0x00025764 },
	{ kPaletteList13, 0x00025764, 0x00025791 },
	{ kPaletteList14, 0x00025791, 0x000257CD },
	{ kPaletteList15, 0x000257CD, 0x000257FA },
	{ kPaletteList16, 0x000257FA, 0x0002581B },
	{ kPaletteList17, 0x0002581B, 0x0002583C },
	{ kPaletteList18, 0x0002583C, 0x00025851 },
	{ kPaletteList19, 0x00025851, 0x00025866 },
	{ kPaletteList20, 0x00025866, 0x0002587B },
	{ kPaletteList21, 0x0002587B, 0x00025890 },
	{ kPaletteList22, 0x00025890, 0x000258A5 },
	{ kPaletteList23, 0x000258A5, 0x000258BA },
	{ kPaletteList24, 0x000258BA, 0x000258EA },
	{ kPaletteList25, 0x000258EA, 0x0002591A },
	{ kPaletteList26, 0x0002591A, 0x0002594A },
	{ kPaletteList27, 0x0002594A, 0x0002597A },
	{ kPaletteList28, 0x0002597A, 0x000259AA },
	{ kPaletteList29, 0x000259AA, 0x000259DA },
	{ kPaletteList30, 0x000259DA, 0x00025A16 },
	{ kPaletteList31, 0x00025A16, 0x00025A3D },
	{ kPaletteList32, 0x00025A3D, 0x00025A64 },
	{ kPaletteList33, 0x00025A64, 0x00025AA0 },
	{ kPutDownString, 0x0002EF50, 0x0002EF76 },
	{ kWaitAmuletString, 0x0002EF76, 0x0002EFB3 },
	{ kBlackJewelString, 0x0002EFB3, 0x0002EFD6 },
	{ kHealingTipString, 0x0002EFD6, 0x0002F003 },
	{ kPoisonGoneString, 0x0002F068, 0x0002F095 },
	{ kHealing1Shapes, 0x0002D703, 0x0002D79D },
	{ kHealing2Shapes, 0x0002D79D, 0x0002D86F },
	{ kThePoisonStrings, 0x0002FCCA, 0x0002FD21 },
	{ kFluteStrings, 0x00032510, 0x000325AC },
	{ kPoisonDeathShapes, 0x0002DB63, 0x0002DBEF },
	{ kFluteShapes, 0x0002DA67, 0x0002DB63 },
	{ kWinter1Shapes, 0x0002D86F, 0x0002D8A0 },
	{ kWinter2Shapes, 0x0002D8A0, 0x0002D995 },
	{ kWinter3Shapes, 0x0002D995, 0x0002D9B1 },
	{ kDrinkShapes, 0x0002D69A, 0x0002D703 },
	{ kWispShapes, 0x0002D9B1, 0x0002DA67 },
	{ kMagicAnimShapes, 0x0002DBEF, 0x0002DC12 },
	{ kBranStoneShapes, 0x0002DC12, 0x0002DC80 },
	{ kWispJewelStrings, 0x0002F003, 0x0002F055 },
	{ kMagicJewelStrings, 0x0002F055, 0x0002F068 },
	{ kFlaskFullString, 0x0002FDE1, 0x0002FDFD },
	{ kFullFlaskString, 0x0002FD4A, 0x0002FDE1 },
	{ kOutroReunionSeq, 0x00031791, 0x00031D76 },
	{ kOutroHomeString, 0x00031E3A, 0x00031E3F },
	{ kVeryCleverString, 0x00031D90, 0x00031DC2 },
	{ kGUIStrings, 0x0002F1EE, 0x0002F3F7 },
	{ kNewGameString, 0x00032CFB, 0x00032D10 },
	{ kConfigStrings, 0x0002fc3d, 0x0002fc9e },
	{ kAudioTracks, 0x00033006, 0x00033047 },
	{ kAudioTracksIntro, 0x0002FE9A, 0x0002FEA6 },
	{ -1, 0, 0 }
};

const ExtractEntry kyra1EngDemo[] = {
	{ kWestwoodLogoSeq, 0x00015327, 0x0001536B },
	{ kKyrandiaLogoSeq, 0x0001536B, 0x000153BF },
	{ kIntroCPSStrings, 0x000154B1, 0x000154BD },
	{ kIntroWSAStrings, 0x000154BD, 0x0001550A },
	{ kIntroCOLStrings, 0x0001550A, 0x00015550 },
	{ kIntroStrings, 0x00015550, 0x0001584A },
	{ kDemo1Seq, 0x000153BF, 0x000153E5 },
	{ kDemo2Seq, 0x000153E5, 0x00015408 },
	{ kDemo3Seq, 0x00015408, 0x00015461 },
	{ kDemo4Seq, 0x00015461, 0x00015481 },
	{ kAudioTracksIntro, 0x00014E6E, 0x00014E74 },
	{ -1, 0, 0 }
};

const Game kyra1EngGames[] = {
	{ kKyra1, EN_ANY, -1, "76a4fc84e173cadb6369785787e1546e", kyra1EngFloppy },
	{ kKyra1, EN_ANY, kTalkieVersion, "1ebc18f3e7fbb72474a55cb0fa089ed4", kyra1EngCD },
	{ kKyra1, EN_ANY, kDemoVersion, "7b7504c8560ffc914d34c44c71b3094c", kyra1EngDemo },
	GAME_DUMMY_ENTRY
};
